==============
Uhull*
==============

A simple (but not simpler) algorithm for concave hull of 2D point sets using an alpha shape algorithm.

Notes
-----
  * uhull! (Brazil) yeah! (expresses joy or celebration)

Homepage
========
* `Project Homepage <https://luanleonardo.github.io/uhull/>`_
